@@ -58,6 +58,7 @@ private:
     float round(float x, int precision);
     void calculateTip();
     void adjustCursorPosition();
+    void manageTaxInputWidgets();
 
 private slots:
     void on_calculateButton_clicked();
@@ -65,10 +66,12 @@ private slots:
     void on_tipAddButton_clicked();
     void on_personsMinusButton_clicked();
     void on_personsAddButton_clicked();
-
-public slots:
     void showSettingsDialog();
     void showAboutDialog();
+    void roundTotal();
+    void roundTip();
+
+public slots:
     void numberClicked(QString value);
     void periodClicked();
     void clearClicked();
